@@ -4,7 +4,7 @@ options(
     setup=Bunch(
         name="stockpyle",
         packages=["stockpyle"],
-        version="0.0.4",
+        version="0.0.5",
         license="BSD",
         author="Matt Pizzimenti",
         author_email="mjpizz+stockpyle@gmail.com",
@@ -32,12 +32,12 @@ Usage
 
 Simplest script that sets up a two-level cache with memcached and local process memory::
 
-    from stockpyle import MultiStore, MemcacheStore, ProcessMemoryStore
+    from stockpyle import ChainedStore, MemcacheStore, ProcessMemoryStore
     
-    # instantiate the MultiStore as a write-through cache
+    # instantiate the ChainedStore as a write-through cache
     pm = ProcessMemoryStore()
     mc = MemcacheStore(servers=["localhost:11711"])
-    store = MultiStore([pm, mc])
+    store = ChainedStore([pm, mc])
     
     # declare a class that is unique for each (bar,zap) combination
     class Foo(object):
@@ -48,7 +48,7 @@ Simplest script that sets up a two-level cache with memcached and local process
             self.bar = bar
             self.zap = zap
     
-    # create and save a Foo to the MultiStore
+    # create and save a Foo to the ChainedStore
     obj = Foo(bar=444, zap=888)
     store.put(obj)
     
@@ -60,18 +60,18 @@ Simplest script that sets up a two-level cache with memcached and local process
 This example isn't that interesting, since we are using two caches.  Let's do one that supports
 SQLAlchemy objects::
 
-    from stockpyle.stores import MultiStore, SqlAlchemyStore, MemcacheStore, ProcessMemoryStore
+    from stockpyle.stores import ChainedStore, SqlAlchemyStore, MemcacheStore, ProcessMemoryStore
     
     pm = ProcessMemoryStore()
     mc = MemcacheStore(servers=["localhost:11711"])
     sa = SqlAlchemyStore()
-    store = MultiStore([pm, mc, sa])
+    store = ChainedStore([pm, mc, sa])
     
     # store it, this will write it through the cache and into the database
     persistent_obj = MySqlAlchemyBackedClass()
     store.put(persistent_obj)
 
-Note the ordering in the MultiStore declaration: the SqlAlchemyStore comes last, since it acts as the final persistence layer.
+Note the ordering in the ChainedStore declaration: the SqlAlchemyStore comes last, since it acts as the final persistence layer.
 Subsequent 'get' requests will attempt process memory, then attempt memcache, and finally check the database.
 
 Also, we can treat the process memory cache and the memcached differently by using different expirations.
@@ -82,7 +82,7 @@ forces Foo objects to be expired more aggressively from the local memory than me
     pm = ProcessMemoryStore()
     mc = MemcacheStore(servers=["localhost:11711"])
     sa = SqlAlchemyStore()
-    store = MultiStore([pm, mc, sa])
+    store = ChainedStore([pm, mc, sa])
     
     # Foo objects will last 60 seconds in local memory, and 5 minutes in memcache
     pm.configure(classes=[Foo], lifetime=60)
