@@ -4,7 +4,7 @@ from sqlalchemy.types import Integer, String
 from sqlalchemy.orm import scoped_session, sessionmaker
 from tests.helpers import CountingStoreWrapper
 from tests.fixture_store import StoreFixture, DeclarativeBase
-from stockpyle._multi import MultiStore
+from stockpyle._chained import ChainedStore
 from stockpyle._procmem import ProcessMemoryStore
 from stockpyle._sqlalchemy import SqlAlchemyStore, SqlAlchemyStoreExtension
 
@@ -21,13 +21,13 @@ class SqlAlchemyStoreTestCase(StoreFixture, TestCase):
         DeclarativeBase.metadata.drop_all()
 
 
-class MultiStoreWithSqlAlchemyTestCase(TestCase):
+class ChainedStoreWithSqlAlchemyTestCase(TestCase):
     
     def setUp(self):        
         DeclarativeBase.metadata.create_all()
         self.__lm = CountingStoreWrapper(ProcessMemoryStore())
         self.__sa = CountingStoreWrapper(SqlAlchemyStore())
-        self.__store = MultiStore([self.__lm, self.__sa])
+        self.__store = ChainedStore([self.__lm, self.__sa])
 
     def tearDown(self):
         DeclarativeBase.metadata.drop_all()
